==> u_team_core-fabric-1.20.1-5.1.4.382-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/item/TestFoodItem.java <==
package info.u_team.u_team_test.test_multiloader.item;

import info.u_team.u_team_core.item.UItem;
import info.u_team.u_team_core.item.food.UFoodPropertiesBuilder;
import info.u_team.u_team_core.util.EnchantmentUtil;
import info.u_team.u_team_core.util.RegistryUtil;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1309;
import net.minecraft.class_1542;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1814;
import net.minecraft.class_1893;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_4174;
import net.minecraft.class_7924;

public class TestFoodItem extends UItem {
	
	private static final class_4174 FOOD = UFoodPropertiesBuilder.builder().method_19238(4).method_19237(1.2F).effect(() -> new class_1293(class_1294.field_5912, 200, 0), 1).method_19240().method_19241().method_19242();
	
	public TestFoodItem() {
		super(new class_1793().method_7894(class_1814.field_8903).method_19265(FOOD));
	}
	
	@Override
	public boolean method_7886(class_1799 stack) {
		return true;
	}
	
	@Override
	public class_1799 method_7861(class_1799 stack, class_1937 level, class_1309 livingEntity) {
		if (livingEntity instanceof class_3222 player) {
			final int enchantment = EnchantmentUtil.getEnchantmentLevel(class_1893.field_9119, stack);
			if (enchantment > 0) {
				final class_1542 itemEntity = player.method_7328(new class_1799(RegistryUtil.getBuiltInRegistry(class_7924.field_41197).method_10240(player.method_6051()).map(reference -> reference.comp_349()).orElse(class_1802.field_20391), enchantment * 5), true);
				if (itemEntity != null) {
					itemEntity.method_6988();
					itemEntity.method_6976();
				}
			}
		}
		return super.method_7861(stack, level, livingEntity);
	}
}

==> u_team_core-fabric-1.21.1-5.6.2.364-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/item/TestFoodItem.java <==
package info.u_team.u_team_test.test_multiloader.item;

import info.u_team.u_team_core.item.UItem;
import info.u_team.u_team_core.item.food.UFoodPropertiesBuilder;
import info.u_team.u_team_core.util.EnchantmentUtil;
import info.u_team.u_team_core.util.RegistryUtil;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1309;
import net.minecraft.class_1542;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1814;
import net.minecraft.class_1893;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_4174;
import net.minecraft.class_7924;

public class TestFoodItem extends UItem {
	
	private static final class_4174 FOOD = UFoodPropertiesBuilder.builder().method_19238(4).method_19237(1.2F).method_19239(new class_1293(class_1294.field_5912, 200, 0), 1).method_19240().method_19241().method_19242();
	
	public TestFoodItem() {
		super(new class_1793().method_7894(class_1814.field_8903).method_19265(FOOD));
	}
	
	@Override
	public boolean method_7886(class_1799 stack) {
		return true;
	}
	
	@Override
	public class_1799 method_7861(class_1799 stack, class_1937 level, class_1309 livingEntity) {
		if (livingEntity instanceof final class_3222 player) {
			final int enchantment = EnchantmentUtil.getEnchantmentLevel(level.method_30349().method_46762(class_7924.field_41265).method_46747(class_1893.field_9119), stack);
			if (enchantment > 0) {
				final class_1542 itemEntity = player.method_7328(new class_1799(RegistryUtil.getBuiltInRegistry(class_7924.field_41197).method_10240(player.method_59922()).map(reference -> reference.comp_349()).orElse(class_1802.field_20391), enchantment * 5), true);
				if (itemEntity != null) {
					itemEntity.method_6988();
					itemEntity.method_6976();
				}
			}
		}
		return super.method_7861(stack, level, livingEntity);
	}
}
